# -*- perl -*-

package Bundle::Mysql;

$VERSION = '1.1817;

1;

__END__

=head1 NAME

Bundle::Msql - A bundle to install Perl drivers for mSQL or MySQL

=head1 SYNOPSIS

C<perl -MCPAN -e 'install Bundle::Msql'>

=head1 CONTENTS

DBI

Data::ShowTable

Msql

DBD::mSQL

=head1 DESCRIPTION

This bundle includes all that's needed to run both DBI drivers and
non-DBI drivers for mSQL or MySQL.

=cut
